import greenfoot.*;

/**
 * A rocket that can be controlled by the arrowkeys: up, left, right.
 * The gun is fired by hitting the 'field' key. 'z' releases a proton wave.
 * 
 * @author Poul Henriksen
 * @author Michael Kölling
 * 
 * @version 1.1
 */
public class Litbunny extends SmoothMover
{
    private static final int gunReloadTime = 5;         // The minimum delay between firing the gun.

    private int reloadDelayCount;               // How long ago we fired the gun the last time.

    private GreenfootImage rocket = new GreenfootImage("Litbunny.png");    
    //private GreenfootImage rocketWithThrust = new GreenfootImage("rocketWithThrust.png");

    /**
     * Initialise this rocket.
     */
    public Litbunny()
    {
        reloadDelayCount = 5;

        addToVelocity ( new Vector (13, 0.3));  

        GreenfootImage image = getImage();
        image.scale(90, 100);
        setImage(image);
    }

    /**
     * Do what a rocket's gotta do. (Which is: mostly flying about, and turning,
     * accelerating and shooting when the right keys are pressed.)
     */
    public void act()
    {
        checkKeys();
        reloadDelayCount++;
        move();
        checkCollision();
    }

    /**
     * Check whether there are any key pressed and react to them.
     */
    private void checkKeys() 
    {
        if (Greenfoot.isKeyDown("space")) 
            fire();

        if (Greenfoot.isKeyDown("z"))
            startProtonWave();

        ignite (Greenfoot.isKeyDown ("up"));

        if (Greenfoot.isKeyDown("left")) 
            turn(- 5);
        if (Greenfoot.isKeyDown("right")) 
            turn(5);

    }

    private void ignite (boolean boosterOn)//ignites the booster on the rocket
    {
        if (boosterOn)
        {
            setImage ("Litbunny.png");
            GreenfootImage image = getImage();
            image.scale(90, 100);
            setImage(image);
            addToVelocity (new Vector (getRotation(), 0.3));
        }
        else
        {
            setImage ("Litbunny.png");
            GreenfootImage image = getImage();
            image.scale(90, 100);
            setImage(image);
        }

    }

    private void checkCollision()
    {

        Actor a = getOneIntersectingObject (Falcon.class);
        if (a != null)

        {
            Field field = (Field) getWorld();
            field.addObject (new Explosion(), getX(), getY());
            field.removeObject (this);
            //field.gameOver();

        }

    }

    /**
     * Fire a bullet if the gun is ready.
     */
    private void fire() 
    {
        if (reloadDelayCount >= gunReloadTime) 
        {
            Egg bullet = new Egg (getVelocity(), getRotation());
            getWorld().addObject (bullet, getX(), getY());
            bullet.move ();
            reloadDelayCount = 0;
        }
    }

    private void startProtonWave()
    {
        ProtonWave wave = new ProtonWave();
        getWorld().addObject (wave, getX(), getY());
    }
}